@@ -156,6 +156,23 @@ class Links(FormatterBase):
                 f['links'] = [ { 'text': text, 'link': link }
                              for text, link in links ]
 
+
+class Up(object):
+    """
+    provides an up link to the path above:
+    /up = ..
+    """
+
+    def __init__(self, arg):
+        self.up = arg.strip()
+    
+    def __call__(self, request, data):
+        path = request.path_info
+        if (path != '/') and self.up:
+            data['files'].insert(0, {'path': '..',
+                                     'name': path.rsplit('/', 1)[0] + '/',
+                                     'description': self.up})
+
 class CSS(object):
     """specify CSS used (whitespace separated list)"""
 
